
#ifndef GlobalHeader2002v0_cxx
#define GlobalHeader2002v0_cxx
#include "GlobalHeader2002v0.h"
#include "TH2.h"
#include "TStyle.h"
#include "TCanvas.h"


GlobalHeader2002v0::GlobalHeader2002v0(TTree *tree,string fileName)
{
// if parameter tree is not specified (or zero), connect the file
// used to generate this class and read the Tree.
   TFile *f ;
   if (tree == 0) {
         f = new TFile(fileName.c_str());

      tree = (TTree*)f->Get("h100");

   }
   Init(tree);
}

GlobalHeader2002v0::~GlobalHeader2002v0()
{
   if (!fChain) return;
//   delete fChain->GetCurrentFile();
}



Int_t GlobalHeader2002v0::GetEntry(Int_t entry)
{
// Read contents of entry.
   if (!fChain) return 0;
   return fChain->GetEntry(entry);
}
Int_t GlobalHeader2002v0::LoadTree(Int_t entry)
{
// Set the environment to read one entry
   if (!fChain) return -5;
   Int_t centry = fChain->LoadTree(entry);
   if (centry < 0) return centry;
   if (fChain->IsA() != TChain::Class()) return centry;
   TChain *chain = (TChain*)fChain;
   if (chain->GetTreeNumber() != fCurrent) {
      fCurrent = chain->GetTreeNumber();
      Notify();
   }
   return centry;
}

void GlobalHeader2002v0::Init(TTree *tree)
{
//   Set branch addresses
   if (tree == 0) return;
   fChain    = tree;
   fCurrent = -1;
   fChain->SetMakeClass(1);

   fChain->SetBranchAddress("runno",&runno);
   fChain->SetBranchAddress("runpd",&runpd);
   fChain->SetBranchAddress("beame",&beame);
   fChain->SetBranchAddress("cryox",&cryox);
   fChain->SetBranchAddress("tabley",&tabley);
   fChain->SetBranchAddress("zbeam",&zbeam);
   fChain->SetBranchAddress("parttype",&parttype);
   Notify();
}

Bool_t GlobalHeader2002v0::Notify()
{
   // Called when loading a new file.
   // Get branch pointers.
   b_runno = fChain->GetBranch("runno");
   b_runpd = fChain->GetBranch("runpd");
   b_beame = fChain->GetBranch("beame");
   b_cryox = fChain->GetBranch("cryox");
   b_tabley = fChain->GetBranch("tabley");
   b_zbeam = fChain->GetBranch("zbeam");
   b_parttype = fChain->GetBranch("parttype");
   return kTRUE;
}

void GlobalHeader2002v0::Show(Int_t entry)
{
// Print contents of entry.
// If entry is not specified, print current entry
   if (!fChain) return;
   fChain->Show(entry);
}
Int_t GlobalHeader2002v0::Cut(Int_t entry)
{
// This function may be called from Loop.
// returns  1 if entry is accepted.
// returns -1 otherwise.
   return 1;
}


void GlobalHeader2002v0::Loop()
{
//   In a ROOT session, you can do:
//      Root > .L GlobalHeader2002v0.C
//      Root > GlobalHeader2002v0 t
//      Root > t.GetEntry(12); // Fill t data members with entry number 12
//      Root > t.Show();       // Show values of entry 12
//      Root > t.Show(16);     // Read and show values of entry 16
//      Root > t.Loop();       // Loop on all entries
//

//     This is the loop skeleton where:
//    jentry is the global entry number in the chain
//    ientry is the entry number in the current Tree
//  Note that the argument to GetEntry must be:
//    jentry for TChain::GetEntry
//    ientry for TTree::GetEntry and TBranch::GetEntry
//
//       To read only selected branches, Insert statements like:
// METHOD1:
//    fChain->SetBranchStatus("*",0);  // disable all branches
//    fChain->SetBranchStatus("branchname",1);  // activate branchname
// METHOD2: replace line
//    fChain->GetEntry(jentry);       //read all branches
//by  b_branchname->GetEntry(ientry); //read only this branch
   if (fChain == 0) return;

   Int_t nentries = Int_t(fChain->GetEntriesFast());

   Int_t nbytes = 0, nb = 0;
   for (Int_t jentry=0; jentry<nentries;jentry++) {
      Int_t ientry = LoadTree(jentry);
      if (ientry < 0) break;
      nb = fChain->GetEntry(jentry);   nbytes += nb;
      // if (Cut(ientry) < 0) continue;
   }
}

#endif // #ifdef GlobalHeader2002v0_cxx
