
#include "CanvasManagerAlg.h"

#include <sstream>
#include <string>
#include <vector>

#include "TStyle.h"

using std::vector;
using std::string;

CanvasManagerAlg::CanvasManagerAlg(Event* event, Geometry* geo, Headers* runHeader):SystemAlg( event,geo,runHeader){
  m_event = event;
  m_geo = geo;
  m_runHeader = runHeader;

  // create the new System Alg Objects
  vector<SystemAlg*> algVector;

  SystemAlg::setAlgs(algVector);

  m_canvasX0    = 10; 
  m_canvasY0    = 10;
  m_canvasX     = 10; 
  m_canvasY     = 10;
  m_canvasNo    = 0;
  m_canvasPadNo = 0;
  m_canvasNx    = 2;
  m_canvasNy    = 2;
  m_canvasDx    = 2;
  m_canvasDy    = 2;
  m_canvasWx    = 1000;
  m_canvasWy    = 774;
  m_canvasBaseTitle = "";
  m_postScriptFileName = "";
  m_psFile = 0;
}

// initialize any variables here
bool CanvasManagerAlg::initialize(){
  SystemAlg::initialize(); // could remove this line
  return true;
}

// put any code you want executed per event here
bool CanvasManagerAlg::execute(){
  SystemAlg::execute(); // could remove this line
  return true;
}

// put any code here that you want executed after all the events have been processed.
bool CanvasManagerAlg::finalize(){
  SystemAlg::finalize(); // could remove this line
  return true;
}
   
// set canvas
void CanvasManagerAlg::setCanvas(string canvasBaseTitle, int canvasNx, int canvasNy, int canvasWx, int canvasWy) {
  m_canvasBaseTitle = canvasBaseTitle;
  m_canvasNx = canvasNx;
  m_canvasNy = canvasNy;
  m_canvasWx = canvasWx;
  m_canvasWy = canvasWy;
  m_canvasX = m_canvasX0;
  m_canvasY = m_canvasY0;
  m_canvasNo = 0;
  m_canvasPadNo = 0;
}

// get next canvas
TCanvas* CanvasManagerAlg::getNextCanvas() {
  std::ostringstream os;
  string c_title = m_canvasBaseTitle;
  string s = (m_canvasBaseTitle == "") ? "" : " ";
  os  << c_title+s << m_canvasNo;
  c_title = os.str();
  TCanvas* C = new TCanvas(c_title.c_str(), c_title.c_str(), m_canvasX, m_canvasY, m_canvasWx, m_canvasWy);
  C->Divide(m_canvasNx, m_canvasNy);
  m_canvasVector.push_back(C);
  ++m_canvasNo;
  return C;
}

// update canvas
void CanvasManagerAlg::updateCanvas() {
  int n = m_canvasVector.size();
  if (n > 0) {
    gPad->Modified();
    m_canvasVector[n-1]->Update();
  }
}

// get next pad
void CanvasManagerAlg::getNextPad() {
  if (m_canvasPadNo%(m_canvasNx*m_canvasNy) == 0) {
    if (m_psFile != 0) m_psFile->NewPage();
    TCanvas* C = getNextCanvas();
    m_canvasX += m_canvasDx;
    m_canvasY += m_canvasDy;
  }
  // need a canvas before opening the postscript file
  if (m_postScriptFileName != "" && m_psFile == 0) {
    openPostScript();
    m_psFile->NewPage();
  }
  // cd into the right pad
  int n = m_canvasVector.size();
  m_canvasVector[n-1]->cd(m_canvasPadNo%(m_canvasNx*m_canvasNy) + 1);
  ++m_canvasPadNo;
}

// set postscript
void CanvasManagerAlg::setPostScript(string postScriptFileName) {
  m_postScriptFileName = postScriptFileName;
}

// open postscript
void CanvasManagerAlg::openPostScript() {
  gStyle->SetPaperSize(21.6, 27.9); // Letter
  m_psFile = new TPostScript(m_postScriptFileName.c_str(), 112); // ps landscape
  m_psFile->Range(26, 20); // set printed page x-y size (cm)
}

// close postscript
void CanvasManagerAlg::closePostScript() {
  m_psFile->Close();
  m_psFile = 0;
}

